import { Component, ChangeDetectionStrategy, forwardRef, ChangeDetectorRef, Input, NgModule, Injectable, EventEmitter, Output, ViewChild, Inject, LOCALE_ID, Directive, ElementRef, Renderer2 } from '@angular/core';
import { CommonModule, getLocaleNumberSymbol, NumberSymbol } from '@angular/common';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS, FormsModule, NgControl } from '@angular/forms';
import { NgbDateParserFormatter, NgbDate, NgbInputDatepicker, NgbDatepickerModule } from '@ng-bootstrap/ng-bootstrap';
import * as momentNs from 'moment';
import Inputmask from 'inputmask';
import { NgSelectModule } from '@ng-select/ng-select';
import { create } from 'nouislider';
import wNumb from 'wnumb';

let nextId$2 = 0;
class CheckboxComponent {
    constructor(cd) {
        this.cd = cd;
        this.value = false;
        this.isDisabled = false;
        this.id = `chk-${nextId$2++}`;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    writeValue(obj) {
        this.value = obj;
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    ngOnInit() {
    }
    onModelChange() {
        this.propagateChange(this.value);
        this.onTouched();
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-checkbox',
                template: "<div class=\"form-check\">\r\n    <input type=\"checkbox\" [disabled]=\"isDisabled\" id=\"{{ 'spot_check' + id }}\" class=\"form-check-input\"\r\n        [(ngModel)]=\"value\" (ngModelChange)=\"onModelChange()\">\r\n    <label class=\"form-check-label\" for=\"{{ 'spot_check' + id }}\">{{ label }}</label>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => CheckboxComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => CheckboxComponent),
                        multi: true,
                    }
                ],
                styles: [""]
            },] }
];
CheckboxComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
CheckboxComponent.propDecorators = {
    label: [{ type: Input }]
};

class CheckboxModule {
}
CheckboxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CheckboxComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [CheckboxComponent]
            },] }
];

const moment$3 = momentNs;
class DatepickerParserFormatter$1 extends NgbDateParserFormatter {
    parse(value) {
        if (!value) {
            return null;
        }
        const date = moment$3.utc(value, 'L', true).toDate();
        return {
            day: date.getDate(),
            month: date.getMonth() + 1,
            year: date.getFullYear()
        };
    } // from input -> internal model
    format(date) {
        if (!date) {
            return '';
        }
        const dt = new Date(date.year, date.month - 1, date.day);
        const result = moment$3(dt).format('L');
        return result;
    }
}
DatepickerParserFormatter$1.decorators = [
    { type: Injectable }
];

// tslint:disable-next-line:max-line-length
const moment$2 = momentNs;
class DatepickerComponent {
    constructor(cd) {
        this.cd = cd;
        this.dateChanged = new EventEmitter();
        this.showIcon = true;
        this.inputClasses = ['form-control'];
        this.autoClose = true;
        this.container = null;
        this.innerValue = null;
        this.isDisabled = false;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    ngOnChanges(changes) {
        this.internalMinDate = this.dateStringToNgbDate(this.minDate);
        this.internalMaxDate = this.dateStringToNgbDate(this.maxDate);
        const inputFormat = moment$2().localeData().longDateFormat('L').toLowerCase();
        const min = this.minDate ? moment$2(this.minDate).format('L') : null;
        const max = this.maxDate ? moment$2(this.maxDate).format('L') : null;
        const mask = new Inputmask({
            alias: 'datetime',
            inputFormat,
            clearMaskOnLostFocus: false,
            min,
            max,
            // nullable: false,
            // positionCaretOnClick: 'none',
            // rightAlign: false
        });
        mask.mask(this.input.nativeElement);
    }
    writeValue(value) {
        if (value) {
            this.value = value;
        }
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    get value() {
        return this.ngbDateToDateString(this.innerValue);
    }
    set value(val) {
        this.innerValue = this.dateStringToNgbDate(val);
        this.propagateChange(val);
        this.cd.markForCheck();
        this.dateChanged.emit(val);
    }
    ngOnInit() {
        this.internalMinDate = this.dateStringToNgbDate(this.minDate);
        this.internalMaxDate = this.dateStringToNgbDate(this.maxDate);
    }
    ngAfterViewInit() {
        const inputFormat = moment$2().localeData().longDateFormat('L').toLowerCase();
        const min = this.minDate ? moment$2(this.minDate).format('L') : null;
        const max = this.maxDate ? moment$2(this.maxDate).format('L') : null;
        const mask = new Inputmask({
            alias: 'datetime',
            inputFormat,
            clearMaskOnLostFocus: false,
            min,
            max,
            // nullable: false,
            // positionCaretOnClick: 'none',
            // rightAlign: false
        });
        mask.mask(this.input.nativeElement);
    }
    ngOnDestroy() {
        this.cd.detach();
    }
    onModelChange() {
        this.propagateChange(this.value);
        this.onTouched();
        this.dateChanged.emit(this.value);
    }
    clear() {
        this.value = null;
    }
    onToggle() {
        if (!this.isDisabled) {
            this.dp.toggle();
            setTimeout(() => {
                const el = document.querySelector('ngb-datepicker');
                if (el) {
                    el.classList.add('ag-custom-component-popup');
                }
            });
        }
    }
    ngbDateToDateString(ngbDate) {
        if (!ngbDate || typeof ngbDate === 'string') {
            return null;
        }
        else {
            return new Date(ngbDate.year, ngbDate.month - 1, ngbDate.day, 22, 0, 0).toISOString();
        }
    }
    dateStringToNgbDate(dateString) {
        const date = new Date(dateString);
        if (date) {
            return new NgbDate(date.getFullYear(), date.getMonth() + 1, date.getDate());
        }
        else {
            return null;
        }
    }
}
DatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-datepicker',
                template: "<div class=\"input-group\">\r\n  <input\r\n    [ngStyle]=\"{ visibility: hide ? 'hidden' : null }\"\r\n    #dp=\"ngbDatepicker\"\r\n    #input\r\n    type=\"text\"\r\n    id=\"orderDate\"\r\n    [class]=\"inputClasses\"\r\n    name=\"dp\"\r\n    ngbDatepicker\r\n    [(ngModel)]=\"innerValue\"\r\n    (ngModelChange)=\"onModelChange()\"\r\n    [disabled]=\"isDisabled\"\r\n    [container]=\"container\"\r\n    [autoClose]=\"autoClose\"\r\n    [minDate]=\"internalMinDate\"\r\n    [maxDate]=\"internalMaxDate\"\r\n  />\r\n  <div class=\"input-group-text pointer\" *ngIf=\"showIcon\" (click)=\"onToggle()\">\r\n    <i class=\"material-icons\"> calendar_today </i>\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => DatepickerComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => DatepickerComponent),
                        multi: true,
                    }
                ]
            },] }
];
DatepickerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
DatepickerComponent.propDecorators = {
    dateChanged: [{ type: Output }],
    showIcon: [{ type: Input }],
    inputClasses: [{ type: Input }],
    autoClose: [{ type: Input }],
    container: [{ type: Input }],
    minDate: [{ type: Input }],
    maxDate: [{ type: Input }],
    hide: [{ type: Input }],
    dp: [{ type: ViewChild, args: [NgbInputDatepicker, { static: true },] }],
    input: [{ type: ViewChild, args: ['input', { static: true },] }]
};

class DatepickerModule {
}
DatepickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatepickerComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    NgbDatepickerModule
                ],
                exports: [DatepickerComponent],
                providers: [
                    { provide: NgbDateParserFormatter, useClass: DatepickerParserFormatter$1 }
                ]
            },] }
];

const moment$1 = momentNs;
class DatepickerParserFormatter extends NgbDateParserFormatter {
    parse(value) {
        if (!value) {
            return null;
        }
        const date = moment$1.utc(value, 'L', true).toDate();
        return {
            day: date.getDate(),
            month: date.getMonth() + 1,
            year: date.getFullYear()
        };
    } // from input -> internal model
    format(date) {
        if (!date) {
            return '';
        }
        const dt = new Date(date.year, date.month - 1, date.day);
        const result = moment$1(dt).format('L');
        return result;
    }
}
DatepickerParserFormatter.decorators = [
    { type: Injectable }
];

const moment = momentNs;
class DaterangepickerComponent {
    constructor(cd, formatter) {
        this.cd = cd;
        this.formatter = formatter;
        this.dateChanged = new EventEmitter();
        this.inputClasses = ['form-control'];
        this.container = null;
        this.innerValueFrom = null;
        this.innerValueTo = null;
        this.isDisabled = false;
        this.hoveredDate = null;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    ngOnChanges(changes) {
        this.internalMinDate = this.dateStringToNgbDate(this.minDate);
        this.internalMaxDate = this.dateStringToNgbDate(this.maxDate);
        const inputFormat = moment().localeData().longDateFormat('L').toLowerCase();
        const min = this.minDate ? moment(this.minDate).format('L') : null;
        const max = this.maxDate ? moment(this.maxDate).format('L') : null;
        const mask = new Inputmask({
            alias: 'datetime',
            inputFormat,
            clearMaskOnLostFocus: false,
            min,
            max,
            // nullable: false,
            // positionCaretOnClick: 'none',
            // rightAlign: false
        });
        mask.mask(this.inputFrom.nativeElement);
        mask.mask(this.inputTo.nativeElement);
    }
    writeValue(val) {
        this.innerValueFrom = val ? this.dateStringToNgbDate(val.from) : null;
        this.innerValueTo = val ? this.dateStringToNgbDate(val.to) : null;
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    onDpToBlur() {
        var _a;
        this.innerValueTo = NgbDate.from(this.formatter.parse(this.inputTo.nativeElement.value));
        if ((_a = this.innerValueTo) === null || _a === void 0 ? void 0 : _a.before(this.innerValueFrom)) {
            this.innerValueFrom = null;
        }
        this.onDateChanged();
    }
    onDpFromBlur() {
        var _a;
        this.innerValueFrom = NgbDate.from(this.formatter.parse(this.inputFrom.nativeElement.value));
        if ((_a = this.innerValueTo) === null || _a === void 0 ? void 0 : _a.before(this.innerValueFrom)) {
            this.innerValueTo = null;
        }
        this.onDateChanged();
    }
    get value() {
        if (this.innerValueFrom && this.innerValueTo) {
            return {
                from: this.ngbDateToDateString(this.innerValueFrom),
                to: this.ngbDateToDateString(this.innerValueTo, true)
            };
        }
        else {
            return null;
        }
    }
    ngOnInit() {
        this.internalMinDate = this.dateStringToNgbDate(this.minDate);
        this.internalMaxDate = this.dateStringToNgbDate(this.maxDate);
    }
    ngAfterViewInit() {
        const inputFormat = moment().localeData().longDateFormat('L').toLowerCase();
        const min = this.minDate ? moment(this.minDate).format('L') : null;
        const max = this.maxDate ? moment(this.maxDate).format('L') : null;
        const mask = new Inputmask({
            alias: 'datetime',
            inputFormat,
            clearMaskOnLostFocus: false,
            min,
            max,
            // nullable: false,
            // positionCaretOnClick: 'none',
            // rightAlign: false
        });
        mask.mask(this.inputFrom.nativeElement);
        mask.mask(this.inputTo.nativeElement);
    }
    ngOnDestroy() {
        this.cd.detach();
    }
    onDateSelection(date) {
        if (!this.innerValueFrom && !this.innerValueTo) {
            this.innerValueFrom = date;
        }
        else if (this.innerValueFrom && !this.innerValueTo && date
            && date.after(this.innerValueFrom)) {
            this.innerValueTo = date;
            this.dp.close();
        }
        else {
            this.innerValueTo = null;
            this.innerValueFrom = date;
        }
        this.onDateChanged();
    }
    onDateChanged() {
        this.propagateChange(this.value);
        this.onTouched();
        this.dateChanged.emit(this.value);
    }
    onToggle() {
        if (!this.isDisabled) {
            this.dp.toggle();
            setTimeout(() => {
                const el = document.querySelector('ngb-datepicker');
                if (el) {
                    el.classList.add('ag-custom-component-popup');
                }
            });
        }
    }
    ngbDateToDateString(ngbDate, isDateTo) {
        if (!ngbDate || typeof ngbDate === 'string') {
            return null;
        }
        else {
            const date = new Date(ngbDate.year, ngbDate.month - 1, ngbDate.day);
            if (isDateTo) {
                date.setHours(23, 59, 59);
            }
            return date.toISOString();
        }
    }
    dateStringToNgbDate(dateString) {
        const date = new Date(dateString);
        if (date) {
            return new NgbDate(date.getFullYear(), date.getMonth() + 1, date.getDate());
        }
        else {
            return null;
        }
    }
    isHovered(date) {
        const hovered = this.innerValueFrom && !this.innerValueTo && this.hoveredDate &&
            date.after(this.innerValueFrom) && date.before(this.hoveredDate);
        return hovered;
    }
    isInside(date) {
        return this.innerValueTo && date.after(this.innerValueFrom) && date.before(this.innerValueTo);
    }
    isRange(date) {
        return date.equals(this.innerValueFrom) ||
            (this.innerValueTo && date.equals(this.innerValueTo)) || this.isInside(date) || this.isHovered(date);
    }
}
DaterangepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-daterangepicker',
                template: "<div class=\"form-group hidden\">\r\n  <div class=\"input-group\">\r\n    <input\r\n      [ngStyle]=\"{ visibility: hide ? 'hidden' : null }\"\r\n      name=\"datepicker\"\r\n      [minDate]=\"internalMinDate\"\r\n      [maxDate]=\"internalMaxDate\"\r\n      class=\"form-control\"\r\n      ngbDatepicker\r\n      #datepicker=\"ngbDatepicker\"\r\n      [autoClose]=\"'outside'\"\r\n      (dateSelect)=\"onDateSelection($event)\"\r\n      [displayMonths]=\"2\"\r\n      [dayTemplate]=\"t\"\r\n      outsideDays=\"hidden\"\r\n      [startDate]=\"innerValueFrom!\"\r\n      [tabIndex]=\"-1\"\r\n      [disabled]=\"isDisabled\"\r\n    />\r\n    <ng-template #t let-date let-focused=\"focused\">\r\n      <span\r\n        class=\"custom-day\"\r\n        [class.focused]=\"focused\"\r\n        [class.range]=\"isRange(date)\"\r\n        [class.faded]=\"isHovered(date) || isInside(date)\"\r\n        (mouseenter)=\"hoveredDate = date\"\r\n        (mouseleave)=\"hoveredDate = null\"\r\n      >\r\n        {{ date.day }}\r\n      </span>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n<div [ngStyle]=\"{ visibility: hide ? 'hidden' : null }\" class=\"input-group\">\r\n  <input\r\n    #inputFrom\r\n    type=\"text\"\r\n    [class]=\"inputClasses\"\r\n    name=\"dpFrom\"\r\n    [disabled]=\"isDisabled\"\r\n    [value]=\"formatter.format(innerValueFrom)\"\r\n    (blur)=\"onDpFromBlur()\"\r\n  />\r\n  <input\r\n    #inputTo\r\n    type=\"text\"\r\n    [class]=\"inputClasses\"\r\n    name=\"dpTo\"\r\n    [value]=\"formatter.format(innerValueTo)\"\r\n    [disabled]=\"isDisabled\"\r\n    (blur)=\"onDpToBlur()\"\r\n  />\r\n\r\n  <div class=\"input-group-text pointer\" (click)=\"onToggle()\">\r\n    <i class=\"material-icons\"> calendar_today </i>\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => DaterangepickerComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => DaterangepickerComponent),
                        multi: true,
                    }
                ],
                styles: [".form-group.hidden{width:0;margin:0;border:none;padding:0;position:absolute}\n"]
            },] }
];
DaterangepickerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NgbDateParserFormatter }
];
DaterangepickerComponent.propDecorators = {
    dateChanged: [{ type: Output }],
    inputClasses: [{ type: Input }],
    container: [{ type: Input }],
    minDate: [{ type: Input }],
    maxDate: [{ type: Input }],
    hide: [{ type: Input }],
    dp: [{ type: ViewChild, args: [NgbInputDatepicker, { static: true },] }],
    inputFrom: [{ type: ViewChild, args: ['inputFrom', { static: true },] }],
    inputTo: [{ type: ViewChild, args: ['inputTo', { static: true },] }]
};

class DaterangepickerModule {
}
DaterangepickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DaterangepickerComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    NgbDatepickerModule
                ], providers: [
                    { provide: NgbDateParserFormatter, useClass: DatepickerParserFormatter }
                ],
                exports: [DaterangepickerComponent]
            },] }
];

class NumericInputComponent {
    constructor(cd, locale) {
        this.cd = cd;
        this.locale = locale;
        this.inputClasses = ['form-control'];
        this.digits = '*';
        this.nullable = false;
        this.rightAlign = false;
        this.digitsOptional = true;
        this.prefix = '';
        this.isDisabled = false;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    get inputValue() {
        const val = this.input.nativeElement.inputmask.unmaskedvalue();
        if (typeof val === 'string' && val !== '') {
            // BUG inputmask!
            return 0;
        }
        if (val === '') {
            return this.nullable ? null : 0;
        }
        return val;
    }
    onInput() {
        this.value = this.inputValue;
        this.onModelChange();
    }
    writeValue(value) {
        if (value) {
            this.value = value;
            this.cd.markForCheck();
            // this.input.nativeElement.inputmask.setValue(value);
        }
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        const mask = new Inputmask({
            alias: 'numeric',
            prefix: this.prefix,
            allowMinus: false,
            allowPlus: false,
            unmaskAsNumber: true,
            radixPoint: getLocaleNumberSymbol(this.locale, NumberSymbol.Decimal),
            groupSeparator: getLocaleNumberSymbol(this.locale, NumberSymbol.Group),
            min: this.min,
            max: this.max,
            digits: this.digits,
            clearMaskOnLostFocus: false,
            nullable: this.nullable,
            positionCaretOnClick: 'none',
            rightAlign: this.rightAlign,
            // digitsOptional: this.digitsOptional
            // placeholder: this.nullable ? '' : '0'
        });
        mask.mask(this.input.nativeElement);
    }
    ngOnDestroy() {
        this.cd.detach();
    }
    focusIn() {
        window.setTimeout(() => {
            this.input.nativeElement.focus();
        });
    }
    onBlur() {
        this.onModelChange();
    }
    selectAllContent($event) {
        this.focusIn();
        setTimeout(() => {
            const tgt = $event.target;
            if (tgt === document.activeElement) {
                tgt.select();
            }
        }, 50);
    }
    onModelChange() {
        this.propagateChange(this.value);
        this.onTouched();
    }
}
NumericInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-numeric-input',
                template: "<input #input type=\"tel\" [class]=\"inputClasses\" name=\"numericinput\" (input)=\"onInput()\"\r\n    (focus)=\"selectAllContent($event)\" (blur)=\"onBlur()\" [disabled]=\"isDisabled\" [value]=\"value\">\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NumericInputComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => NumericInputComponent),
                        multi: true,
                    }
                ],
                styles: [""]
            },] }
];
NumericInputComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] }
];
NumericInputComponent.propDecorators = {
    inputClasses: [{ type: Input }],
    digits: [{ type: Input }],
    nullable: [{ type: Input }],
    min: [{ type: Input }],
    max: [{ type: Input }],
    rightAlign: [{ type: Input }],
    digitsOptional: [{ type: Input }],
    prefix: [{ type: Input }],
    input: [{ type: ViewChild, args: ['input', { static: true },] }]
};

class NumericInputModule {
}
NumericInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NumericInputComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [NumericInputComponent]
            },] }
];

let nextId$1 = 0;
class RadioComponent {
    constructor(cd) {
        this.cd = cd;
        this.id = `chk-${nextId$1++}`;
        this.isDisabled = false;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    writeValue(obj) {
        this.value = obj;
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    ngOnInit() {
    }
    onModelChange($event) {
        this.propagateChange($event);
        this.onTouched();
    }
}
RadioComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-radio',
                template: "<div class=\"form-check\" *ngFor=\"let item of items\">\r\n    <input name=\"spot_radio_{{ id }}\" [disabled]=\"isDisabled\" type=\"radio\" id=\"spot_radio_{{ id }}_{{ item.value }}\"\r\n        class=\"form-check-input\" (ngModelChange)=\"onModelChange($event)\" [value]=\"item.value\" [(ngModel)]=\"value\">\r\n    <label class=\"form-check-label\" for=\"spot_radio_{{ id }}_{{ item.value }}\" translate>{{item.label}}</label>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => RadioComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => RadioComponent),
                        multi: true,
                    }
                ],
                styles: [":host{display:block}\n"]
            },] }
];
RadioComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
RadioComponent.propDecorators = {
    items: [{ type: Input }]
};

class RadioModule {
}
RadioModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RadioComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [RadioComponent]
            },] }
];

let nextId = 0;
class SwitchComponent {
    constructor(cd) {
        this.cd = cd;
        this.value = false;
        this.isDisabled = false;
        this.id = `sw-${nextId++}`;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    writeValue(obj) {
        this.value = obj;
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    ngOnInit() {
    }
    onModelChange() {
        this.propagateChange(this.value);
        this.onTouched();
    }
}
SwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-switch',
                template: "<div class=\"form-check form-switch\">\r\n    <input type=\"checkbox\" [disabled]=\"isDisabled\" class=\"form-check-input\" id=\"spot-sw-{{ id }}\"\r\n        [(ngModel)]=\"value\" (ngModelChange)=\"onModelChange()\">\r\n    <label class=\"form-check-label\" for=\"spot-sw-{{ id }}\">{{ label }} </label>\r\n</div>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => SwitchComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => SwitchComponent),
                        multi: true,
                    }
                ],
                styles: [""]
            },] }
];
SwitchComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
SwitchComponent.propDecorators = {
    label: [{ type: Input }]
};

class SwitchModule {
}
SwitchModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SwitchComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [SwitchComponent]
            },] }
];

class FormControlValidatorMessageProvider {
    constructor() {
        this.defaultValidationMessages = {
            required: 'campo obbligatorio',
            min: 'il valore minimo è _min',
            max: 'il valore massimo è _max',
            pattern: 'formato non valido',
            email: 'formato non valido',
            maxlength: 'il limite massimo di caratteri è _maxlength',
            jsonFormat: 'formato JSON non valido',
            digit: 'è ammessa solo una cifra',
            requiredOneLocalizationItem: 'inserire almeno una lingua'
        };
    }
    getMessage(key, errorInfo) {
        let msg = this.defaultValidationMessages[key] || '';
        if (msg.indexOf('_') > -1 && errorInfo) {
            Object.keys(errorInfo).forEach(ph => {
                msg = msg.replace('_' + ph, errorInfo[ph]);
            });
        }
        return msg;
    }
}
FormControlValidatorMessageProvider.decorators = [
    { type: Injectable }
];

class CoreControlValidatorDirective {
    constructor(el, renderer, messageProvider) {
        this.el = el;
        this.renderer = renderer;
        this.messageProvider = messageProvider;
        this.showTooltip = false;
        this.addErrorFeedback = true;
        this.errorMessages = {};
        this.submittedForm = false;
        this.markAlways = false;
        this.child = this.renderer.createElement('div');
        this.child.className = 'invalid-feedback';
    }
    get htmlElement() {
        return this.el.nativeElement;
    }
    checkValidity() {
        if (this.addValidationErrors()) {
            let errors = '';
            const errorInfos = this.getErrors();
            Object.keys(errorInfos).forEach((key, i) => {
                const errorInfo = errorInfos[key];
                errors += (i > 0 ? '<br>' : '') + this.messageProvider.getMessage(key, errorInfo);
            });
            if (!this.htmlElement.classList.contains('is-invalid')) {
                this.htmlElement.classList.add('is-invalid');
            }
            if (this.showTooltip) {
                this.el.nativeElement.title = errors;
            }
            if (this.addErrorFeedback) {
                this.child.innerHTML = errors;
                this.renderer.appendChild(this.htmlElement.parentElement, this.child);
            }
        }
        else {
            if (this.htmlElement.classList.contains('is-invalid')) {
                this.htmlElement.classList.remove('is-invalid');
            }
            this.el.nativeElement.title = '';
            if (this.addErrorFeedback && this.child.parentElement) {
                this.renderer.removeChild(this.htmlElement.parentElement, this.child, false);
            }
        }
    }
}
CoreControlValidatorDirective.decorators = [
    { type: Directive }
];
CoreControlValidatorDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: FormControlValidatorMessageProvider }
];
CoreControlValidatorDirective.propDecorators = {
    showTooltip: [{ type: Input }],
    addErrorFeedback: [{ type: Input }],
    errorMessages: [{ type: Input }],
    submittedForm: [{ type: Input }],
    markAlways: [{ type: Input }]
};

class FormControlValidatorDirective extends CoreControlValidatorDirective {
    constructor(formControl, el, renderer, messageProvider) {
        super(el, renderer, messageProvider);
        this.formControl = formControl;
    }
    ngOnInit() {
        this.formControl.valueChanges.subscribe(() => {
            this.checkValidity();
        });
    }
    ngOnChanges() {
        if (this.submittedForm) {
            this.checkValidity();
        }
    }
    addValidationErrors() {
        return this.formControl.invalid && (this.formControl.dirty || this.submittedForm || this.markAlways);
    }
    getErrors() {
        return this.formControl.errors;
    }
}
FormControlValidatorDirective.decorators = [
    { type: Directive, args: [{
                selector: '[spotFormControlValidator]'
            },] }
];
FormControlValidatorDirective.ctorParameters = () => [
    { type: NgControl },
    { type: ElementRef },
    { type: Renderer2 },
    { type: FormControlValidatorMessageProvider }
];

class FormControlValidatorModule {
}
FormControlValidatorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FormControlValidatorDirective],
                imports: [
                    CommonModule
                ],
                providers: [
                    FormControlValidatorMessageProvider
                ],
                exports: [
                    FormControlValidatorDirective
                ]
            },] }
];

class SelectComponent {
    constructor(cd) {
        this.cd = cd;
        this.changed = new EventEmitter();
        this.isDisabled = false;
        this.propagateChange = (value) => { };
        this.validateFn = () => { };
        this.onTouched = () => { };
    }
    writeValue(obj) {
        this.value = obj;
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.cd.markForCheck();
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    ngOnInit() {
    }
    onModelChange($event) {
        this.changed.emit($event);
        this.propagateChange($event);
        this.onTouched();
    }
}
SelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-select',
                template: "<ng-select (ngModelChange)=\"onModelChange($event)\" [clearable]=\"clearable\" [disabled]=\"isDisabled\" [items]=\"items\"\r\n  [bindLabel]=\"bindLabel\" [bindValue]=\"bindValue\" [(ngModel)]=\"value\" [appendTo]=\"appendTo\" [searchable]=\"searchable\"\r\n  [placeholder]=\"placeholder\">\r\n</ng-select>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => SelectComponent),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => SelectComponent),
                        multi: true,
                    }
                ],
                styles: [""]
            },] }
];
SelectComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
SelectComponent.propDecorators = {
    bindLabel: [{ type: Input }],
    bindValue: [{ type: Input }],
    appendTo: [{ type: Input }],
    clearable: [{ type: Input }],
    searchable: [{ type: Input }],
    items: [{ type: Input }],
    placeholder: [{ type: Input }],
    changed: [{ type: Output }]
};

class SelectModule {
}
SelectModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SelectComponent],
                imports: [
                    CommonModule,
                    FormsModule,
                    NgSelectModule
                ],
                exports: [SelectComponent]
            },] }
];

class SliderComponent {
    constructor(cd) {
        this.cd = cd;
        this.currentValue = [];
        this.propagateChange = (value) => { };
        this.onTouched = () => { };
        this.validateFn = () => { };
    }
    writeValue(value) {
        if (value) {
            this.currentValue = value;
        }
        this.cd.markForCheck();
    }
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    validate(control) {
        const res = this.validateFn(control);
        return res;
    }
    init() {
        this.slider = create(this.sliderRef.nativeElement, {
            start: this.values,
            connect: true,
            range: {
                min: this.min,
                max: this.max
            },
            tooltips: this.tooltips,
            step: this.step,
            format: wNumb({
                decimals: this.decimal
            })
        });
        this.slider.on('change', () => {
            this.currentValue = this.slider.get();
            this.propagateChange(this.slider.get());
            this.onTouched();
        });
    }
    ngOnInit() {
        this.init();
    }
    ngOnDestroy() {
        this.cd.detach();
    }
    ngOnChanges(changes) {
    }
    onModelChange($event) {
        this.propagateChange($event);
        this.onTouched();
    }
}
SliderComponent.decorators = [
    { type: Component, args: [{
                selector: 'spot-slider',
                template: "<div id=\"slider\" #slider></div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => SliderComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => SliderComponent),
                        multi: true,
                    }
                ],
                styles: ["::ng-deep .noUi-connect{background:var(--primary)}\n"]
            },] }
];
SliderComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
SliderComponent.propDecorators = {
    sliderRef: [{ type: ViewChild, args: ['slider', { static: true },] }],
    min: [{ type: Input }],
    max: [{ type: Input }],
    values: [{ type: Input }],
    tooltips: [{ type: Input }],
    step: [{ type: Input }],
    decimal: [{ type: Input }]
};

class SliderModule {
}
SliderModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SliderComponent],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [SliderComponent]
            },] }
];

class AngularComponentsModule {
}
AngularComponentsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    DatepickerModule,
                    NumericInputModule,
                    FormControlValidatorModule,
                    CheckboxModule,
                    RadioModule,
                    SwitchModule,
                    DaterangepickerModule,
                    SelectModule,
                    SliderModule
                ],
                exports: [
                    DatepickerModule,
                    NumericInputModule,
                    FormControlValidatorModule,
                    CheckboxModule,
                    RadioModule,
                    SwitchModule,
                    DaterangepickerModule,
                    SelectModule,
                    SliderModule
                ],
                providers: []
            },] }
];

/*
 * Public API Surface of angular-components
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularComponentsModule, CheckboxComponent, CheckboxModule, CoreControlValidatorDirective, DatepickerComponent, DatepickerModule, DaterangepickerComponent, DaterangepickerModule, FormControlValidatorDirective, FormControlValidatorMessageProvider, FormControlValidatorModule, NumericInputComponent, NumericInputModule, RadioComponent, RadioModule, SelectComponent, SelectModule, SliderComponent, SliderModule, SwitchComponent, SwitchModule, DatepickerParserFormatter$1 as ɵa, DatepickerParserFormatter as ɵb };
//# sourceMappingURL=spotsoftware-angular-components.js.map
